Index: test/mjsunit/function-arguments-null.js |
diff --git a/test/mjsunit/function-arguments-null.js b/test/mjsunit/function-arguments-null.js |
index 21e542fc81e7a93362a886810ad7076443efecc5..6b47a10188b8ab2a97bca2d1731dec4241523eaa 100644 |
--- a/test/mjsunit/function-arguments-null.js |
+++ b/test/mjsunit/function-arguments-null.js |
@@ -25,6 +25,9 @@ |
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE |
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
// The arguments property of functions should be null when not |
// executing inside the function. |
-assertTrue(toString.arguments === null); |
+ |
+function sloppy() {} |
+ |
+assertTrue(sloppy.arguments === null); |
@@ -25,6 +25,9 @@ |
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE |
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
-// The arguments property of functions should be null when not |
+// The arguments property of sloppy functions should be null when not |
// executing inside the function. |